%
%  This script calls Andy Rhines' routine to get a sounding from the
%  University of Wyoming and plots the buoyancy of parcels lifted from
%  various levels. 
%-------------------------------------------------------------------------
pmin=850;       % Minimum parcel origin pressure (hPa)
ptop=80;        % Minimum pressure (hPa) for graphical display
Bmin=-5;        % Minimum buoyancy (C) for graphs
Bmax=8;         % Maximum buoyancy (C) for graphs
Yaxis='log';    % Scaling of pressure axis for plots ('linear' or 'log')
%--------------------------------------------------------------------------
place=input('Enter 5-digit station ID or place name (in single quotations) ');
if max(size(place)) > 1
    [u,states,nations,status]=getids(place);
    if status == 0
        disp(' ')
        disp('No such place')
        return
    end    
    usize=max(size(u));
    if usize > 1
        disp(' ')
        disp('Possible station numbers:')
        for i=1:usize
            disp([num2str(u(i)),char(' '),char(states(i)),char(' '),char(nations(i))])
        end    
        disp(' ')
        station_id=input('Which one do you want? (5-digit identifier) ');
    else
        station_id=u;
    end
else
    station_id=place;
end    
A=input('Enter year, month, day,GMT time (e.g. [2014 7 3 0])');
year=A(1);
month=A(2);
day=A(3);
hour=A(4);
%
[data,header,status] = getsounding(station_id,year,month,day,hour);
if status == 0
    disp('No data for this station and time')
    return
end    
%
%  Eliminate levels with NaNs
%
pt=data(:,1);
Tt=data(:,3);
rt=0.001*data(:,6);
q=max(size(pt));
n=0;
T=zeros(1,q);
p=T;
r=T;
ptemp=2000;
for i=1:q
    if isnan(pt(i)) == 0 && isnan (Tt(i)) == 0 && isnan(rt(i)) == 0 && pt(i) < ptemp
        n=n+1;
        ptemp=pt(i);
        T(n)=Tt(i)+273.15;
        p(n)=pt(i);
        r(n)=rt(i);
    end
end    
T(n+1:q)=[];
p(n+1:q)=[];
r(n+1:q)=[];
Tv=T.*(1+r/0.622)./(1+r);
ptop=max(ptop,p(n));
%
% Now cycle through parcel origin levels
%
ni=0;
Brev=zeros(n,n);
Bpseudo=Brev;
for i=1:n
    if p(i) >= pmin
        ni=ni+1;
        clear plift Tlift rslift Tliftpa rsliftpa
        plift=p(i+1:end);
        [ Tlift,rslift] = svinvert( T(i),r(i),p(i),plift );
        Trowlift=Tlift.*(1+rslift/0.622)./(1+r(i));
        nlift=max(size(Trowlift));
        Brev(i,i+1:nlift+i)=Trowlift-Tv(i+1:nlift+i);
        [ Tliftpa,rsliftpa] = svinvertpa( T(i),r(i),p(i),plift );
        Trowliftpa=Tliftpa.*(1+rsliftpa/0.622)./(1+rsliftpa);        
        Bpseudo(i,i+1:nlift+i)=Trowliftpa-Tv(i+1:nlift+i);
    end
end    
%
Brev=max(Brev,Bmin);       % Bound buoyancies
Bpseudo=max(Bpseudo,Bmin);
Brev=min(Brev,Bmax);       
Bpseudo=min(Bpseudo,Bmax);
%
%  Contour solutions
%
contourf(p,p,Brev')
set(gca,'xdir','reverse','ydir','reverse')
set(gca,'ytick',100:100:1000)
set(gca,'xlim',[pmin p(1)],'ylim',[ptop p(1)])
set(gca,'Yscale',Yaxis)
set(gca,'clim',[Bmin Bmax])
set(gca,'fontweight','bold')
xlabel('Parcel Origin Pressure (hPa)')
ylabel('Pressure (hPa)')
j=colorbar;
set(j,'fontweight','bold')
titstring=['Station ',num2str(station_id),'  ',num2str(year),'/', ...
    num2str(month),'/',num2str(day),'/', num2str(hour),' Reversible Buoyancy (K)'];
title(titstring)
%
disp(' ')
disp('Hit return for next plot')
pause
%
contourf(p,p,Bpseudo')
set(gca,'xdir','reverse','ydir','reverse')
set(gca,'ytick',100:100:1000)
set(gca,'xlim',[pmin p(1)],'ylim',[ptop p(1)])
set(gca,'Yscale',Yaxis)
set(gca,'clim',[Bmin Bmax])
set(gca,'fontweight','bold')
xlabel('Parcel Origin Pressure (hPa)')
ylabel('Pressure (hPa)')
j=colorbar;
set(j,'fontweight','bold')
titstring=['Station ',num2str(station_id),'  ',num2str(year),'/', ...
    num2str(month),'/',num2str(day),'/', num2str(hour),' Pseudo Buoyancy (K)'];
title(titstring)
%